# pymotion [![Build Status](https://travis-ci.com/ludeeus/pymotion.svg?branch=master)](https://travis-ci.com/ludeeus/pymotion) [![PyPI version](https://badge.fury.io/py/pymotion.svg)](https://badge.fury.io/py/pymotion)

_Python API wrapper for Motion webcontrol._

## Prerequisites

To use this you need to make sure that both these settings has these values:
You will find these in the `motion.conf` file.

```
webcontrol_localhost off
webcontrol_html_output off
```

## Install

```bash
pip install pymotion
```

Look at the file `example.py` for a usage example.